function [L_opt,dh_opt,dlef_opt,alpha_opt,sigma_opt] = ss_opt_calculator(A,B,C_s,D_s,r)
%   SS_OPT_CALCULATOR Compute optimal steady state solution
%
%       Author: T.S.C. Pollack
%       Copyright (2024) T.S.C. Pollack

    za = A(1,1); zq = A(1,2); ma = A(2,1); mq = A(2,2);
    zdh = B(1,1); zdlef = B(1,2); mdh = B(2,1); mdlef = B(2,2);

    zq_bar    = zq - za/ma*mq;
    zdh_bar   = zdh - za/ma*mdh;
    zdlef_bar = zdlef - za/ma*mdlef;
    mq_bar    = mq - mdlef/zdlef_bar*zq_bar;
    mdh_bar   = mdh - mdlef/zdlef_bar*zdh_bar;

    Ca = C_s(:,1); Cq = C_s(:,2); Ddh = D_s(:,1); Ddlef = D_s(:,2);

    Cr      = Cq - Ca/ma*mq_bar - Ddlef/zdlef_bar*zq_bar;
    Ddh_bar = Ddh - Ca/ma*mdh_bar - Ddlef/zdlef_bar*zdh_bar;

    [dh_opt,L_opt,~,~] = fmincon(@(x)Ldh(x,r,Cr,Ddh_bar),0);

    dlef_opt  = -1/(zdlef_bar)*(zq_bar*r+zdh_bar*dh_opt);
    alpha_opt = -1/ma*(mq*r + mdh*dh_opt + mdlef*dlef_opt);
    sigma_opt = C_s*[alpha_opt;r] + D_s*[dh_opt;dlef_opt];
    
end