function [P,N,Kfb,Kff,S,RE] = indare(A,B,C,D,Wr,TT,By,delta_T)
%   INDARE Solve incremental normalized discrete Algebraic Riccati Equation
%   (ARE) to compute optimal control allocation solution
%
%       Author: T.S.C. Pollack
%       Copyright (2024) T.S.C. Pollack

    % Get dimensions
    nx = size(A,1); nu = size(B,2); n = nx + nu; 

    % Get pseudo-inverse and null-space matrices
    Ri = (D'*D + Wr)\eye(nu);
    P  = Ri*By'*((By*Ri*By')\1);
    N  = eye(nu) - P*By;
    
    % Create closed-loop system
    A = A - B*P*TT(1:nx);
    [A,B,~,~] = ssdata(c2d(ss(A,B,eye(nx),zeros(nx,nu)),delta_T));
    
    % Create augmented system
    A = [          A , B*N;
          -P*TT(1:nx) , N  ];
    B = [B;eye(nu)];
    V = [C D];
    Y = V - D*P*TT;    
    
    % Hamiltonian sub-matrices
    E = A - B*N*Ri*D'*V;
    F = B*N*Ri*B';
    G = -(Y'*D -(P*TT)'*Wr)*N*Ri*B';
    H = Y'*Y + (P*TT)'*Wr*P*TT - (Y'*D - (P*TT)'*Wr)*N*Ri*D'*V;

    % Apply QZ-factorization
    L = [eye(n), F; zeros(n,n), A' + G];
    M = [E, zeros(n,n); -H, eye(n)];
    
    [MM,LL,Q,Z] = qz(M,L,'real');
    
    % Order generalized eigenvalues
    [MMS,LLS,QS,ZS] = ordqz(MM,LL,Q,Z,'udi');
    
    % Generate feedback costate matrix    
    U11 = ZS(1:n,1:n);
    U21 = ZS(n+1:end,1:n);
    S = U21*inv(U11);    
    
    % Riccati equation
    Rti = inv(eye(nu) + N*Ri*B'*S*B);
    M   = S*B*Rti*N*Ri*(D'*V+B'*S*A);
    
    RE = A'*S*A - A'*M + G*S*A - G*M + H - S;

    % Tracking costate
    Q = Y'*D - (P*TT)'*Wr + (A' + G)*S*B*(eye(nu) - Rti*N*Ri*B'*S*B);
    Z = eye(n) - (A' + G)*(eye(n) - S*B*Rti*N*Ri*B');

    % Control gains    
    Kfb = Rti*N*Ri*(D'*V + B'*S*A);
    Kff = Rti*N*Ri*B'*(S*B + Z\(Q))*P;

end