%==========================================================================
% [plt_lin_bl.m] Generates subfigures in Figure 5.7
%   Plot broken-loop responses for different CA configurations
%
%   Author: T.S.C. Pollack
%   Copyright (2024) T.S.C. Pollack
%==========================================================================

close all; clear all; clc;

% Set broken-loop path
bl_open = 'nu'; % 'nu' ,'dd', 'dh', 'dlef'

%% Import data

% Add path
addpath('_MISC');

% 1. Baseline (NO LEF)
load('..\..\..\_FIGDATA\3_BL\LIN_F16_NOLEF_h10kft_V500fts_kp5\umbrella.mat');

if strcmp(bl_open,'nu')
    L_INCA_NOLEF = LIN_F16_CL_BL_NU;      
elseif strcmp(bl_open,'dd')
    L_INCA_NOLEF = LIN_F16_CL_BL_DD;        
elseif strcmp(bl_open,'dh')
    L_INCA_NOLEF = LIN_F16_CL_BL_DH;    
elseif strcmp(bl_open,'dlef')
    L_INCA_NOLEF = LIN_F16_CL_BL_DLEF;        
end

% 2. INCA
load('..\..\..\_FIGDATA\3_BL\LIN_F16_INCA_TSS_h10kft_V500fts_kp5\umbrella.mat');

if strcmp(bl_open,'nu')
    L_INCA = LIN_F16_CL_BL_NU;      
elseif strcmp(bl_open,'dd')
    L_INCA = LIN_F16_CL_BL_DD;        
elseif strcmp(bl_open,'dh')
    L_INCA = LIN_F16_CL_BL_DH;    
elseif strcmp(bl_open,'dlef')
    L_INCA = LIN_F16_CL_BL_DLEF;        
end

% 3. INOC
load('..\..\..\_FIGDATA\3_BL\LIN_F16_INOC_TSS_h10kft_V500fts_kp5\umbrella.mat');

if strcmp(bl_open,'nu')
    L_INOC = LIN_F16_CL_BL_NU;      
elseif strcmp(bl_open,'dd')
    L_INOC = LIN_F16_CL_BL_DD;        
elseif strcmp(bl_open,'dh')
    L_INOC = LIN_F16_CL_BL_DH;    
elseif strcmp(bl_open,'dlef')
    L_INOC = LIN_F16_CL_BL_DLEF;        
end

%% PLOTTING

% Set plotting theme
clr_lst   = color_theme();
clr_order = [3,1,5];
style_lst = {'-','-','-','-'};

% Get Bode data
FIG_BL = figure; omega = logspace(-2,2,71);

[mag_L_INCA_NOLEF,phase_L_INCA_NOLEF,~] = bode(L_INCA_NOLEF,omega); 
phase_L_INCA_NOLEF = phase_wrapper(phase_L_INCA_NOLEF(:));

[mag_L_INCA,phase_L_INCA,~] = bode(L_INCA,omega);
phase_L_INCA = phase_wrapper(phase_L_INCA(:));

[mag_L_INOC,phase_L_INOC,~] = bode(L_INOC,omega);
phase_L_INOC = phase_wrapper(phase_L_INOC(:));

% Plot 
sp1 = subplot(2,1,1);
semilogx(omega,mag2db(mag_L_INCA_NOLEF(:)),'color',clr_lst(clr_order(1),:),'LineStyle',style_lst{1}); grid on; hold on;
semilogx(omega,mag2db(mag_L_INCA(:)),'color',clr_lst(clr_order(2),:),'LineStyle',style_lst{2});
semilogx(omega,mag2db(mag_L_INOC(:)),'color',clr_lst(clr_order(3),:),'LineStyle',style_lst{3});
ylabel('Magnitude (dB)','Interpreter','latex','FontSize',12);
set(gca,'TickLabelInterpreter','latex')
set(gca,'XTickLabel',[])

sp1.Position = sp1.Position + [0 -0.05 0 0.05];

sp2 = subplot(2,1,2);
semilogx(omega,phase_L_INCA_NOLEF,'color',clr_lst(clr_order(1),:),'LineStyle',style_lst{1}); grid on; hold on;
semilogx(omega,phase_L_INCA,'color',clr_lst(clr_order(2),:),'LineStyle',style_lst{1});
semilogx(omega,phase_L_INOC,'color',clr_lst(clr_order(3),:),'LineStyle',style_lst{1});
xlabel('Frequency (rad/s)','Interpreter','latex','FontSize',12);
ylabel('Phase (deg)','Interpreter','latex','FontSize',12);
set(gca,'TickLabelInterpreter','latex')

sp2.Position = sp2.Position + [0 0 0 0.05];

