%==========================================================================
% [plt_lin_uncbatch.m] Generates subfigures in Figure 5.6
%   Generate uncertain linear step response diagrams
%
%   Author: T.S.C. Pollack
%   Copyright (2024) T.S.C. Pollack
%==========================================================================

clear all; close all; clc;

%% User settings

% Add function paths
addpath('_MISC'); addpath('../0_MISC')

% Set data directory
cd('..\..\..\_FIGDATA\2_LIN\2_UNCERTAIN\_dB_secondary_control_INCA');

% Set plotting theme
clr_lst   = color_theme();
clr_order = [1,5,6,5,1];
style_lst = {'-','--','-','--','-'};

% Set plotting horizon
Tplt = [0.8,8];

%% Plot

% Scan data
dir_lst = dir; dir_lst = dir_lst(3:end);

% Create figure
FIG = figure(1); FIG.Position = [300 59 560 380*1];

% Loop
j = 0;

for i = 1:length(dir_lst)
    
    j = j + 1;
    
    if j == length(dir_lst)-1
        lst_idx = length(clr_order);
    elseif j == length(dir_lst)-2
        lst_idx = length(clr_order)-1;
    else        
        lst_idx = min(j,length(clr_order)-2);
    end

    load(dir_lst(j).name);

    T = ref.Time;

    if j == 1
        sp1 = subplot(3,1,1);
        sp1.Position = sp1.Position+ [-0.02 -0.01 0.05 0.04];
        plot(sp1,T,ref.Data(:,2),'r--'); grid on; hold on;
    end
        
    plot(sp1,T,y_sim.Data(:,2),'color',clr_lst(clr_order(lst_idx),:),...
        'LineStyle',style_lst{lst_idx});
    ylabel(sp1,'q (deg/s)','Interpreter','latex','FontSize',12);
    set(sp1,'TickLabelInterpreter','latex')
    set(sp1,'XTickLabel',[])
    xlim(Tplt);

    if j == 1
        sp2 = subplot(3,1,2);
        sp2.Position = sp2.Position+ [-0.02 -0.01 0.05 0.04];
    end
    
    plot(sp2,T,y_sim.Data(:,1),'color',clr_lst(clr_order(lst_idx),:),...
        'LineStyle',style_lst{lst_idx}); grid on; hold on;
    ylabel(sp2,'$\alpha$ (deg)','Interpreter','latex','FontSize',12);
    set(sp2,'TickLabelInterpreter','latex')
    set(sp2,'XTickLabel',[])
    xlim(Tplt);

    if j == 1
        sp3 = subplot(3,1,3);
        sp3.Position = sp3.Position+ [-0.02 -0.01 0.05 0.04];
    end
    
    plot(sp3,T,L.Data,'color',clr_lst(clr_order(lst_idx),:),'LineStyle',...
        style_lst{lst_idx}); grid on; hold on;
    xlabel(sp3,'Time (s)','Interpreter','latex','FontSize',12);
    ylabel(sp3,'$L$ (-)','Interpreter','latex','FontSize',12);
    set(sp3,'TickLabelInterpreter','latex')
    xlim(Tplt);
    
    if j == 1
        axzoom = axes('position',[.715 .125 .2 .15]);
        box on; grid on; hold on;
        zoomidx = (T < 8) & (T > 6);
    end
    
    plot(axzoom,T(zoomidx),L.Data(zoomidx),'color',...
        clr_lst(clr_order(lst_idx),:),'LineStyle',style_lst{lst_idx}); 
    axis tight;
    ylim(axzoom,[2.2,2.8])
    set(axzoom,'TickLabelInterpreter','latex')
    set(axzoom,'XTickLabel',[])
    
end