%==========================================================================
% [batch_lintss.m] Generate batch linear incremental control allocation 
% and optimal control results (time-scale separation [TSS] leveraged)
%
%   Author: T.S.C. Pollack
%   Copyright (2024) T.S.C. Pollack
%==========================================================================

% Default synthesis airframe system
A_def = ba_lon_sys.A;
B_def = ba_lon_sys.B;
C_def = [1/CDref*ba_lon_sys.C(5,:)',zeros(2,2)]';
D_def = [1/CDref*ba_lon_sys.D(5,:)',kp*sqrt(Wp)]';

% Run A matrix batch
for dA11 = dAtab{1,1}
    for dA12 = dAtab{1,2}
        for dA21 = dAtab{2,1}
            for dA22 = dAtab{2,2}    
                
                % Perturbed synthesis system
                A = A_def.*(1+[dA11, dA12; dA21, dA22]);
                B = B_def;
                C = C_def;
                D = D_def;
                
                % Generate optimal restoring control law
                By = B(2,:);

                % Primary state feedback matrix - assuming perfect cancellation of Ax
                TT = [K_p*[0,1] + A(2,:), By];

                % Generate restoring control law
                if strcmp(ctrlmode,'inoc_tss')    
                    [P,N,Ks,Kx,Kr,X,H] = indare_tss(A,B,C,D,kr^2*Wr,TT,By,delta_T);
                elseif strcmp(ctrlmode,'inca_tss')    
                    [P,N,Ks,Kx,Kr] = kica_tss(C,D,kr^2*Wr,By);
                end
                
                sim('F16_LTI_INOC_TSS.slx');
                
                str_idx = strcat('dA',num2str(dA11),...
                    num2str(dA12),num2str(dA21),num2str(dA22));
                save(strcat(fsname,'_',str_idx,'.mat'));
                
            end
        end
    end
end

% Run B matrix batch
for dB11 = dBtab{1,1}
    for dB12 = dBtab{1,2}
        for dB21 = dBtab{2,1}
            for dB22 = dBtab{2,2}      
                
                % Perturbed synthesis system
                A = A_def;
                B = B_def.*(1+[dB11, dB12; dB21, dB22]);
                C = C_def;
                D = D_def;
                
                % Generate optimal restoring control law
                By = B(2,:);

                % Primary state feedback matrix - assuming perfect cancellation of Ax
                TT = [K_p*[0,1] + A(2,:), By];

                % Generate restoring control law
                if strcmp(ctrlmode,'inoc_tss')    
                    [P,N,Ks,Kx,Kr,X,H] = indare_tss(A,B,C,D,kr^2*Wr,TT,By,delta_T);
                elseif strcmp(ctrlmode,'inca_tss')    
                    [P,N,Ks,Kx,Kr] = kica_tss(C,D,kr^2*Wr,By);
                end
                
                sim('F16_LTI_INOC.slx');
                
                str_idx = strcat('dB',num2str(dB11),...
                    num2str(dB12),num2str(dB21),num2str(dB22));
                save(strcat(fsname,'_',str_idx,'.mat'));
                
            end
        end
    end
end

% Run C matrix batch
for dC11 = dCtab{1,1}
    for dC12 = dCtab{1,2}   
        
        % Perturbed synthesis system
        A = A_def;
        B = B_def;
        C = C_def.*(1+[dC11, dC12; zeros(2,2)]);
        D = D_def;

        % Generate optimal restoring control law
        By = B(2,:);

        % Primary state feedback matrix - assuming perfect cancellation of Ax
        TT = [K_p*[0,1] + A(2,:), By];

        % Generate restoring control law
        if strcmp(ctrlmode,'inoc_tss')    
            [P,N,Ks,Kx,Kr,X,H] = indare_tss(A,B,C,D,kr^2*Wr,TT,By,delta_T);
        elseif strcmp(ctrlmode,'inca_tss')    
            [P,N,Ks,Kx,Kr] = kica_tss(C,D,kr^2*Wr,By);
        end

        sim('F16_LTI_INOC.slx');
        
        str_idx = strcat('dC',num2str(dC11),num2str(dC12));
        save(strcat(fsname,'_',str_idx,'.mat'));
        
    end
end

% Run D matrix batch
for dD11 = dDtab{1,1}
    for dD12 = dDtab{1,2}            
        % Perturbed synthesis system
        A = A_def;
        B = B_def;
        C = C_def;
        D = D_def.*(1+[dD11, dD12; zeros(2,2)]);

        % Generate optimal restoring control law
        By = B(2,:);

        % Primary state feedback matrix - assuming perfect cancellation of Ax
        TT = [K_p*[0,1] + A(2,:), By];

        % Generate restoring control law
        if strcmp(ctrlmode,'inoc_tss')    
            [P,N,Ks,Kx,Kr,X,H] = indare_tss(A,B,C,D,kr^2*Wr,TT,By,delta_T);
        elseif strcmp(ctrlmode,'inca_tss')    
            [P,N,Ks,Kx,Kr] = kica_tss(C,D,kr^2*Wr,By);
        end

        sim('F16_LTI_INOC.slx');
        
        str_idx = strcat('dD',num2str(dD11),num2str(dD12));
        save(strcat(fsname,'_',str_idx,'.mat'));
        
    end
end